==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/qasmixer/src/mwdg/mixer_sliders_proxies_group.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "mixer_sliders_proxies_column.hpp"
#include "wdg/pad_proxies_group.hpp"
#include <QString>
#include <QTimer>

namespace MWdg
{

/// @brief Mixer_Sliders_Proxies_Group
///
class Mixer_Sliders_Proxies_Group : public ::Wdg::Pad_Proxies_Group
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Mixer_Sliders_Proxies_Group ( QObject * parent_n = nullptr );

  ~Mixer_Sliders_Proxies_Group ();

  // -- Mixer_Simple_Elem

  ::QSnd::Mixer_Simple_Elem *
  mixer_simple_elem () const
  {
    return _mixer_simple_elem;
  }

  virtual void
  set_mixer_simple_elem ( ::QSnd::Mixer_Simple_Elem * selem_n );

  // -- Snd dir

  unsigned char
  snd_dir () const
  {
    return _snd_dir;
  }

  void
  set_snd_dir ( unsigned char dir_n );

  // -- Joined flag

  bool
  is_joined () const
  {
    return _is_joined;
  }

  void
  set_is_joined ( bool flag_n );

  // If true then the corresponding widget is visible

  bool
  is_visible () const
  {
    return _is_visible;
  }

  void
  set_is_visible ( bool flag_n );

  // -- Notify parent on value change

  bool
  notify_value_change () const
  {
    return _notify_value_change;
  }

  void
  set_notify_value_change ( bool flag_n );

  // -- Separation info

  bool
  can_be_separated () const;

  bool
  should_be_separated () const;

  bool
  needs_separation () const;

  bool
  separation_request () const
  {
    return _separation_request;
  }

  void
  set_separation_request ( bool flag_n );

  // -- Public slots

  Q_SLOT
  void
  update_mixer_values ();

  // -- Protected slots
  protected:
  Q_SLOT
  void
  timer_separation_check ();

  // Protected methods
  protected:
  bool
  event ( QEvent * event_n ) override;

  // Private attributes
  private:
  ::QSnd::Mixer_Simple_Elem * _mixer_simple_elem;
  unsigned char _snd_dir;
  bool _is_joined;
  bool _is_visible;
  bool _notify_value_change;
  bool _separation_request;
  QTimer _separation_timer;
};

} // namespace MWdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/qasmixer/src/mwdg/mixer_sliders_proxies_group.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "mixer_sliders_proxies_column.hpp"
#include "wdg/pad_proxies_group.hpp"
#include <QString>
#include <QTimer>

namespace MWdg
{

/// @brief Mixer_Sliders_Proxies_Group
///
class Mixer_Sliders_Proxies_Group : public Wdg::Pad_Proxies_Group
{
  Q_OBJECT

  public:
  // -- Construction

  Mixer_Sliders_Proxies_Group ( QObject * parent_n = nullptr );

  ~Mixer_Sliders_Proxies_Group ();

  // -- Mixer_Simple_Elem

  QSnd::Mixer::Elem *
  mixer_simple_elem () const
  {
    return _mixer_simple_elem;
  }

  virtual void
  set_mixer_simple_elem ( QSnd::Mixer::Elem * selem_n );

  // -- Snd dir

  unsigned char
  snd_dir () const
  {
    return _snd_dir;
  }

  void
  set_snd_dir ( unsigned char dir_n );

  // -- Joined flag

  bool
  is_joined () const
  {
    return _is_joined;
  }

  void
  set_is_joined ( bool flag_n );

  // If true then the corresponding widget is visible

  bool
  is_visible () const
  {
    return _is_visible;
  }

  void
  set_is_visible ( bool flag_n );

  // -- Notify parent on value change

  bool
  notify_value_change () const
  {
    return _notify_value_change;
  }

  void
  set_notify_value_change ( bool flag_n );

  // -- Separation info

  bool
  can_be_separated () const;

  bool
  should_be_separated () const;

  bool
  needs_separation () const;

  bool
  separation_request () const
  {
    return _separation_request;
  }

  void
  set_separation_request ( bool flag_n );

  // -- Public slots

  Q_SLOT
  void
  update_mixer_values ();

  // -- Protected slots
  protected:
  Q_SLOT
  void
  timer_separation_check ();

  protected:
  // -- Protected methods

  bool
  event ( QEvent * event_n ) override;

  private:
  // -- Attributes
  QSnd::Mixer::Elem * _mixer_simple_elem;
  unsigned char _snd_dir;
  bool _is_joined;
  bool _is_visible;
  bool _notify_value_change;
  bool _separation_request;
  QTimer _separation_timer;
};

} // namespace MWdg
